@@ -581,26 +581,6 @@ check_device_settings (GPilotDevice *device)
 			g_free (str);
 			return FALSE;
 		}
-	} else if (device->type == PILOT_DEVICE_USB_VISOR) {
-		struct stat sb;
-			
-		if (stat (device->port, &sb) != 0) {
-			str = g_strdup_printf ("%s\n%s (%s)\n%s\n%s (%d)",
-					       _("Could not examine the port for"),
-					       device->name, device->port,
-					       _("The port should point to a USB serial port"),
-					       g_strerror (errno), errno);	  
-			error_dialog (NULL, str);
-			g_free (str);
-			return FALSE;
-		} else if (!S_ISCHR (sb.st_mode)) {
-			str = g_strdup_printf ("%s\n%s (%s)",
-					       _("The port should be a character special device but isn't for"),
-					       device->name, device->port);
-			error_dialog (NULL, str);
-			g_free (str);
-			return FALSE;
-		}
 	}
 
 	return TRUE;
