@@ -48,6 +48,9 @@
 #include <stdio.h>
 #include <fcntl.h>
 
+#include <libxml/xmlmemory.h>
+#include <libxml/entities.h>
+
 #include <libgnome/libgnome.h>
 
 #include <pi-source.h>
@@ -787,53 +790,76 @@ network_device_err (GIOChannel *io_channel,
 
 #ifdef WITH_USB_VISOR
 #ifdef linux
-static const char *vendor_product_ids[] =
-{
-	"Vendor=082d ProdID=0100", /* Handspring Visor/Treo 300 */
-	"Vendor=082d ProdID=0200", /* Handspring Treo */
-	"Vendor=0830 ProdID=0001", /* Palm M500 */
-	"Vendor=0830 ProdID=0002", /* Palm M505 */
-	"Vendor=0830 ProdID=0003", /* Palm M515 */
-	"Vendor=0830 ProdID=0020", /* Palm I705 */
-	"Vendor=0830 ProdID=0040", /* Palm M125 */
-	"Vendor=0830 ProdID=0050", /* Palm M130 */
-	"Vendor=0830 ProdID=0060", /* Palm Tungsten T */
-	"Vendor=0830 ProdID=0031", /* Palm Tungsten Z */
-	"Vendor=0830 ProdID=0070", /* Palm Zire */
-	"Vendor=0830 ProdID=0080", /* Palm M100 */
-	"Vendor=054c ProdID=0038", /* Sony Clie 3.5 */
-	"Vendor=054c ProdID=0066", /* Sony Clie 4.0 */
-	"Vendor=054c ProdID=0095", /* Sony Clie S360 */
-	"Vendor=054c ProdID=009a", /* Sony Clie 4.1 */
-	"Vendor=054c ProdID=00da", /* Sony Clie NX60 */
-	"Vendor=054c ProdID=00c9", /* Sony Clie NZ90V */
-	"Vendor=04e8 ProdID=8001", /* Samsung SCH-I330 */
-	NULL
-};
+static GPtrArray *vendor_product_ids = NULL;
+static GArray *product_net = NULL;
 
-static gboolean product_net[] =
+static void
+load_devices_xml (void) 
 {
-       FALSE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       TRUE,
-       -1
-};
+	xmlDoc *doc = NULL;
+	xmlNode *root, *node;
+	char *filename;
+	
+	if (vendor_product_ids)
+		return;
+	
+	vendor_product_ids = g_ptr_array_new ();
+	product_net = g_array_new (FALSE, FALSE, sizeof (gboolean));
+
+	filename = g_build_filename (DEVICE_XML_DIR, "devices.xml", NULL);
+	doc = xmlParseFile (filename);
+	g_free (filename);
+		
+	if (!doc) {
+		g_warning ("Unable to read device file at %s", filename);
+		
+		return;
+	}
+
+	root = xmlDocGetRootElement (doc);
+	if (!root->name || strcmp (root->name, "device-list"))
+		goto fail;
+	
+	for (node = root->children; node; node = node->next) {
+		xmlChar *vendor, *product, *net;
+		gboolean use_net;
+		
+		if (node->type != XML_ELEMENT_NODE)
+			continue;
+
+		if (!node->name || strcmp (node->name, "device")) {
+			g_warning ("Invalid sub node %s", node->name ? node->name : "");
+
+			continue;
+		}
+		
+		vendor = xmlGetProp (node, "vendor_id");
+		product = xmlGetProp (node, "product_id");
+
+		if (!vendor || !product) {
+			g_warning ("No vendor or product id");
+
+			continue;
+		}
+		
+		g_message ("Found %s, %s", vendor, product);
+		g_ptr_array_add (vendor_product_ids, g_strdup_printf ("Vendor=%s ProdID=%s", vendor, product));
+
+		xmlFree (vendor);
+		xmlFree (product);
+		
+		net = xmlGetProp (node, "use_net");
+		use_net = !net || strcmp (net, "false");
+		
+		g_message ("Using net %s", use_net ? "TRUE" : "FALSE");
+		g_array_append_val (product_net, use_net);
+
+		xmlFree (net);
+	}
+
+ fail:
+	xmlFreeDoc (doc);
+}
 
 static gboolean 
 visor_devices_timeout (gpointer data) 
@@ -853,19 +879,25 @@ visor_devices_timeout (gpointer data)
 	if (context->paused) 
 		return FALSE;
 
+	load_devices_xml ();
+	
 	/* Check /proc/bus/usb/devices for a usb device */
 	f = fopen ("/proc/bus/usb/devices", "r");
+	if (!f)
+		f = fopen ("/proc/bus/usb/devices_please-use-sysfs-instead", "r");
+	if (!f)
+		return TRUE;
 	
 	while (fgets (line, 255, f) != NULL && !visor_exists) {
 		if (line[0] != 'P')
 			continue;
 		
-		for (i = 0; vendor_product_ids[i] != NULL; i++) {
+		for (i = 0; i < vendor_product_ids->len; i++) {
 			if (!g_strncasecmp (line + strlen ("P:  "), 
-				      vendor_product_ids[i], 
-				      strlen (vendor_product_ids[i]))) {
+				      vendor_product_ids->pdata[i], 
+				      strlen (vendor_product_ids->pdata[i]))) {
 				visor_exists = TRUE;
-				visor_net = product_net[i];
+				visor_net = product_net->data[i];
 			}
 		}
 	}
