@@ -32,11 +32,9 @@
 
 /* the LOG macro cannot by used without a format */
 #ifdef GPC_DEBUG
-#define LOG(format,args...) g_log (G_LOG_DOMAIN, \
-                                   G_LOG_LEVEL_MESSAGE, \
-                                   "gpilotd: " format, ##args)
+#define LOG(x) g_message x
 #else
-#define LOG(format,args...)
+#define LOG(x)
 #endif
 
 
